#========================================================================================================================
# Annotated code for Zonghang Zhang et al. (submitted to 'Animals' in June 2021)                                                             #
# "A comparative study on two territorial fishes: the influence of physical enrichment on aggressive behavior"                                                #
# This code was written by Zonghang Zhang at Ocean University of China                                                                     #
# Some codes were adapted from the anonymous reviewer's comments.
#========================================================================================================================


# load packages
library(readxl)
library(car) 
library(lme4) 
library(lsmeans)


# load dataset 
dataset <- read_excel("Supplementary Data.xlsx")
str(dataset) #check if all variables are correctly recognized


# run genelized linear model using black rockfish data
model <- glm(aggression.rockfish ~ treatment*time, family=poisson, data=dataset) #treatment, time and their interaction as fixed factors 

Anova(model) #get test statistics, degrees of freedom and p-values per fixed factor 
pairs(lsmeans(model, ~treatment:time), adjust="tukey") #all post-hoc contrasts (Tukey-corrected) 
pairs(lsmeans(model, ~treatment|time), adjust="tukey") #post-hoc contrasts (Tukey-corrected) among treatments per timepoint 
pairs(lsmeans(model, ~time|treatment), adjust="tukey") #post-hoc contrasts (Tukey-corrected) among timepoints per treatment 


# run genelized linear model using fat greenling data
model2 <- glm(aggression.greenling ~ treatment*time, family=poisson, data=dataset) #treatment, time and their interaction as fixed factors 

Anova(model2) #get test statistics, degrees of freedom and p-values per fixed factor 
pairs(lsmeans(model2, ~treatment:time), adjust="tukey") #all post-hoc contrasts (Tukey-corrected) 
pairs(lsmeans(model2, ~treatment|time), adjust="tukey") #post-hoc contrasts (Tukey-corrected) among treatments per timepoint 
pairs(lsmeans(model2, ~time|treatment), adjust="tukey") #post-hoc contrasts (Tukey-corrected) among timepoints per treatment 


#-------- END -----------